# -*- coding: utf-8 -*-
"""
pythonnest core package.
"""
__author__ = 'Matthieu Gallet'
__version__ = '1.0.2'
